@@ -1,13 +1,15 @@
 import os
 import json
-import logging
-import click
 from flask import Flask, render_template, jsonify, send_from_directory, request
 from flask_swagger import swagger
-from localstack.constants import VERSION
-from localstack.utils.aws.aws_stack import Environment
+from localstack import config
 from localstack.utils import common
+from localstack.services import generic_proxy, plugins
+from localstack.services import infra as services_infra
+from localstack.constants import VERSION, LOCALSTACK_WEB_PROCESS
 from localstack.dashboard import infra
+from localstack.utils.bootstrap import load_plugins, canonicalize_api_names
+from localstack.utils.aws.aws_stack import Environment
 
 
 root_path = os.path.dirname(os.path.realpath(__file__))
@@ -34,12 +36,33 @@ def get_graph():
             - name: request
               in: body
     """
-    data = get_payload(request)
+    data = get_payload()
     env = Environment.from_string(data.get('awsEnvironment'))
     graph = infra.get_graph(name_filter=data['nameFilter'], env=env)
     return jsonify(graph)
 
 
+@app.route('/services', methods=['GET'])
+def get_status():
+    """ Get status of deployed services
+        ---
+        operationId: 'getStatus'
+    """
+    result = services_infra.get_services_status()
+    return jsonify(result)
+
+
+@app.route('/services', methods=['POST'])
+def set_status():
+    """ Set status of deployed services
+        ---
+        operationId: 'setStatus'
+    """
+    data = get_payload()
+    result = services_infra.set_service_status(data)
+    return jsonify(result)
+
+
 @app.route('/kinesis/<streamName>/<shardId>/events/latest', methods=['POST'])
 def get_kinesis_events(streamName, shardId):
     """ Get latest events from Kinesis.
@@ -53,7 +76,7 @@ def get_kinesis_events(streamName, shardId):
             - name: request
               in: body
     """
-    data = get_payload(request)
+    data = get_payload()
     env = Environment.from_string(data.get('awsEnvironment'))
     result = infra.get_kinesis_events(stream_name=streamName, shard_id=shardId, env=env)
     return jsonify(result)
@@ -70,12 +93,28 @@ def get_lambda_code(functionName):
             - name: request
               in: body
     """
-    data = get_payload(request)
+    data = get_payload()
     env = Environment.from_string(data.get('awsEnvironment'))
     result = infra.get_lambda_code(func_name=functionName, env=env)
     return jsonify(result)
 
 
+@app.route('/health')
+def get_health():
+    # TODO: this should be moved into a separate service, once the dashboard UI is removed
+    reload = request.args.get('reload') is not None
+    result = plugins.get_services_health(reload=reload)
+    return jsonify(result)
+
+
+@app.route('/health', methods=['PUT'])
+def put_health():
+    data = get_payload()
+    plugins.set_services_health(data)
+    result = {'status': 'OK'}
+    return jsonify(result)
+
+
 @app.route('/')
 def hello():
     return render_template('index.html')
@@ -86,7 +125,7 @@ def send_static(path):
     return send_from_directory(web_dir + '/', path)
 
 
-def get_payload(request):
+def get_payload():
     return json.loads(common.to_str(request.data))
 
 
@@ -99,12 +138,12 @@ def ensure_webapp_installed():
 
 
 def serve(port):
+    os.environ[LOCALSTACK_WEB_PROCESS] = '1'
     ensure_webapp_installed()
+    load_plugins()
+    canonicalize_api_names()
 
-    def noecho(*args, **kwargs):
-        pass
+    backend_url = 'http://localhost:%s' % port
+    services_infra.start_proxy(config.PORT_WEB_UI_SSL, backend_url, use_ssl=True)
 
-    click.echo = noecho
-    logging.getLogger('werkzeug').setLevel(logging.ERROR)
-    app.config['ENV'] = 'development'
-    app.run(port=int(port), debug=True, threaded=True, host='0.0.0.0')
+    generic_proxy.serve_flask_app(app=app, port=port, quiet=True)
